/* $VER: DMCopyChkVer 1.3 (24.2.03) by J. Tierney

  DiskMaster Copy - Check Version  v1.3
  2/24/03  J. Tierney

  Function:  Copies selected files to dest. window, first comparing their
            version strings.

  Requires:  DoVer
             PIPE: device.

  Usage:  DMCopyChkVer.rexx <auto> <defchoice>

          <auto> - 0 - Pops up a requester every time a file already exists.
                   1 - Pops up a req. only when no version string is found.

  Example DM2 Usage: Copy-ChkVer, 10, REXX DMCopyChkVer.rexx 1
*/

dover = 'C:DoVer'  /* Change this to whereever DoVer is located on your system. */


OPTIONS RESULTS

ARG auto .

IF auto ~= 1 THEN auto = 0

who = ADDRESS()

STATUS P
sdir = FixPath(result)

STATUS D
ddir = FixPath(result)

pipe = 'PIPE:' || who || 'ChkVer'

DIRLIST VAR dlist SEL
DO i = 1 TO dlist.name.0
  src = sdir || dlist.name.i
  dest = ddir || dlist.name.i
  IF EXISTS(dest) THEN DO
    ADDRESS COMMAND dover '>' || pipe '"' || src || '"' 'FMT %v NOCOMM'
    CALL OPEN('io', pipe, 'R')
      line = READLN('io')
    CALL CLOSE('io')
    sver = GetVer(line)
    ADDRESS COMMAND dover '>' || pipe '"' || dest || '"' 'FMT %v NOCOMM'
    CALL OPEN('io', pipe, 'R')
      line = READLN('io')
    CALL CLOSE('io')
    dver = GetVer(line)

    IF CompareVers(sver, dver, auto, src) = 0 THEN ITERATE
  END
  ADDRESS COMMAND 'C:Copy' '"' || src || '"' 'TO' '"' || ddir '" CLONE'
END

DESELECT '*'
CALL CLOSE('io')
EXIT 0


/* --- Procedures --- */

FixPath: PROCEDURE
  PARSE ARG pathstr

  IF (RIGHT(pathstr, 1) ~= ':') & (RIGHT(pathstr, 1) ~= '/') THEN pathstr = pathstr || '/'
RETURN pathstr


GetVer: PROCEDURE
  PARSE ARG line
  x = POS('09'x || '- ', line)
  IF x = 0 THEN DO
    ver = 0
    END
  ELSE DO
    ver = SUBSTR(line, x + 3)
    IF DATATYPE(LEFT(ver, 1), 'N') = 0 THEN ver = 0
  END
RETURN ver


CompareVers:  PROCEDURE
  PARSE ARG sv, dv, auto, name

  srcgtr = 0
  lf = '|'

  IF (sv ~= 0) & (dv ~= 0) THEN DO
    IF auto THEN DO
      srcgtr = sv > dv
      END
    ELSE DO
      bodytext = 'File: ' name || lf || 'Source version: ' sv || lf || 'Dest. Version:  ' dv
      'Confirm "' || bodytext || '"' Copy Skip
      IF rc = 0 THEN srcgtr = 1
    END
    END
  ELSE DO
    bodytext = 'File: ' name || lf || 'No version string found.'
    'Confirm "' || bodytext || '"' Copy Skip
    IF rc = 0 THEN srcgtr = 1
  END
RETURN srcgtr
