/* $VER: DM_IdxRename.rexx 1.2 (25.2.03) by J.Tierney

  DiskMaster II Indexed Rename  v1.2
  2/25/03  by J. Tierney <jodytierney@earthlink.net>

  Purpose:  Renames selected files to one name plus an index.

            A requester will allowing you to enter the base filename
            and starting index number.

            The starting index consists of one or more plus-signs ("+"),
            which will reserve space for the index, followed by the number
            to begin counting at.
            Ex:  "+1" = 1 digit index = "1", "2", "3", ...
                "++1" = 2 digit index = "01", "02" "03", ...
               "+++5" = 3 digit index = "005", "006", "007", ...

  Usage:  REXX DMIdxRename.rexx

  Example:
    Entered in requester:  Mountain++1.jpg
    Selected files are renamed to "Mountain01.jpg", "Mountain02.jpg", etc.

    Entered in requester:  Page-+++5
    Files renamed to:  "Page-005", "Page-006", "Page-007", ...
*/

OPTIONS RESULTS

'STATUS S'
IF result = 0 THEN EXIT

'CONFIRM "Enter new name:" Okay Cancel ++1'
If rc = 1 THEN EXIT 0

pat = result

DIRLIST VAR dlist SEL

STATUS P
path = result
IF RIGHT(path, 1) ~= ':' THEN path = path || '/'

idx.places = ''

DO i = 1 TO dlist.name.0
  newname = MakeNewName(pat, dlist.name.i)
  ADDRESS COMMAND 'C:Rename "' || path || dlist.name.i || '" TO "' || path || newname || '"'
END

'DESELECT *'
EXIT 0


MakeNewName:  PROCEDURE EXPOSE idx.
  PARSE ARG pat, oldname

  s = POS('+', pat)
  IF s > 0 THEN DO
    IF idx.places = '' THEN DO
      DO x = 1 UNTIL SUBSTR(pat, s + x, 1) ~= '+'
      END
      idx.places = x

      DO n = 0 UNTIL ~DATATYPE(SUBSTR(pat, s + x + n, 1), 'N')
      END
      idx.extra = n
      IF n > 0 THEN DO
        str = SUBSTR(pat, s + x, n)
        idx.num = str - 1
        END
      ELSE DO
        idx.num = 0
      END
    END

    newname = DELSTR(pat, s, idx.places + idx.extra)
    idx.num = idx.num + 1
    newname = INSERT(RIGHT(idx.num, idx.places, '0'), newname, s - 1)
  END
RETURN newname

